==> datovka_4.9.3.1+rb2.orig.tar.xz: datovka-4.9.3.1+rb2/src/views/lowered_tree_view.cpp <==
/*
 * Copyright (C) 2014-2017 CZ.NIC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations including
 * the two.
 */

#include <QHeaderView>

#include "src/dimensions/dimensions.h"
#include "src/views/lowered_tree_view.h"

QSize LoweredItemDelegate::sizeHint(const QStyleOptionViewItem &option,
    const QModelIndex &index) const
{
	return QSize(QItemDelegate::sizeHint(option, index).width(),
	    Dimensions::tableLineHeight(option));
}

LoweredTreeView::LoweredTreeView(QWidget *parent)
    : QTreeView(parent)
{
}

void LoweredTreeView::setNarrowedLineHeight(void)
{
	setItemDelegate(new (std::nothrow) LoweredItemDelegate());
	setUniformRowHeights(true);

	/*
	 * Force header height.
	 *
	 * TODO -- Find a better solution, the following line does not work
	 *     on Windows.
	 */
	//header()->setFixedHeight(Dimensions::tableLineHeight(viewOptions()));
}

==> datovka-4.25.0.tar.xz: datovka-4.25.0/src/views/lowered_tree_view.cpp <==
/*
 * Copyright (C) 2014-2024 CZ.NIC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations including
 * the two.
 */

#include <QHeaderView>

#include "src/dimensions/dimensions.h"
#include "src/views/lowered_tree_view.h"

QSize LoweredItemDelegate::sizeHint(const QStyleOptionViewItem &option,
    const QModelIndex &index) const
{
	return QSize(QItemDelegate::sizeHint(option, index).width(),
	    Dimensions::tableLineHeight(option));
}

LoweredTreeView::LoweredTreeView(QWidget *parent)
    : QTreeView(parent)
{
}

void LoweredTreeView::setNarrowedLineHeight(void)
{
	setItemDelegate(new (::std::nothrow) LoweredItemDelegate());
	setUniformRowHeights(true);

	/*
	 * Force header height.
	 *
	 * TODO -- Find a better solution, the following line does not work
	 *     on Windows.
	 */
	//header()->setFixedHeight(Dimensions::tableLineHeight(viewOptions()));
}
